@@ -1,4 +1,5 @@
 from ._format import *
 from ._utils import *
 from ._composite import *
-from . import themes
+from ._xarray import *
+# from . import themes
